@@ -4,8 +4,6 @@ use Modern::Perl;
 use Moose;
 use MooseX::Method::Signatures;
 
-use Carp;
-use Readonly;
 use List::MoreUtils qw/ any  all /;
 
 use Project::Euler::Lib::Types qw/ PosInt  PosIntArray /;
@@ -64,6 +62,7 @@ The check number must be divisible by all numbers in the array
 has 'multi_nums' => (
     is          => 'rw',
     isa         => PosIntArray,
+    lazy_build  => 1,
     required    => 1,
 );
 
