@@ -22,11 +22,11 @@ Project::Euler::Problem::P001 - Solutions for problem 001
 
 =head1 VERSION
 
-Version 0.1.1
+Version v0.1.2
 
 =cut
 
-use version 0.77; our $VERSION = qv("v0.1.1");
+use version 0.77; our $VERSION = qv("v0.1.2");
 
 =head1 SYNOPSIS
 
@@ -273,4 +273,4 @@ See http://dev.perl.org/licenses/ for more information.
 #  Cleanup the Moose stuff
 no Moose;
 __PACKAGE__->meta->make_immutable;
-1; # End of Project::Eulerl::Problem::P001
+1; # End of Project::Euler::Problem::P001
